@@ -26,7 +26,7 @@ public:
                                                ViewManager::ContextView},
                                               {{i18nc("@title:window Title of the view of recently played tracks", "Recently Played")},
                                                QUrl{QStringLiteral("image://icon/media-playlist-play")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByRecentlyPlayed,
                                                ElisaUtils::Track,
@@ -36,11 +36,10 @@ public:
                                                Qt::DescendingOrder,
                                                {i18nc("@item:inmenu", "Least Recently Played First"), i18nc("@item:inmenu", "Most Recently Played First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of frequently played tracks", "Frequently Played")},
                                                QUrl{QStringLiteral("image://icon/view-media-playcount")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByFrequentlyPlayed,
                                                ElisaUtils::Track,
@@ -50,8 +49,7 @@ public:
                                                Qt::DescendingOrder,
                                                {i18nc("@item:inmenu", "Least Frequently Played First"), i18nc("@item:inmenu", "Most Frequently Played First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of all albums", "Albums")},
                                                QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                                                ViewManager::GridView,
@@ -82,7 +80,7 @@ public:
                                                ViewManager::ViewHideRating},
                                               {{i18nc("@title:window Title of the view of all tracks", "Tracks")},
                                                QUrl{QStringLiteral("image://icon/view-media-track")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Track,
@@ -99,8 +97,7 @@ public:
                                                 i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
                                                 i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of all genres", "Genres")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::GridView,
@@ -128,7 +125,7 @@ public:
                                               },
                                               {{i18nc("@title:window Title of the file radios browser view", "Radio Stations")},
                                                QUrl{QStringLiteral("image://icon/radio")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Radio,
@@ -138,8 +135,7 @@ public:
                                                Qt::AscendingOrder,
                                                {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsRadio}};
+                                               ViewManager::NoDiscHeaders}};
 
     const int mNumOfBaseViews = mViewsParameters.count();
 
@@ -323,7 +319,7 @@ void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
 
         d->mViewsParameters.push_back({oneAlbum.title(),
                                        coverImage,
-                                       ViewManager::ListView,
+                                       ViewManager::TrackView,
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::FilterById,
                                        oneAlbum.databaseId(),
@@ -335,8 +331,7 @@ void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
                                        Qt::AscendingOrder,
                                        {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        ViewManager::SingleAlbum,
-                                       ViewManager::DiscHeaders,
-                                       ViewManager::IsTrack});
+                                       ViewManager::DiscHeaders});
     }
     Q_EMIT dataAdded();
 }
